// Copyright (C) 2022 The Qt Company Ltd.
// Copyright (C) 2019 Alexey Edelev <semlanik@gmail.com>
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTPROTOBUFQTCORETYPES_H
#define QTPROTOBUFQTCORETYPES_H

#include <QtProtobufQtCoreTypes/qtprotobufqtcoretypesglobal.h>

QT_BEGIN_NAMESPACE

namespace QtProtobuf {

Q_PROTOBUFQTCORETYPES_EXPORT void registerProtobufQtCoreTypes();

}

QT_END_NAMESPACE

#endif // QTPROTOBUFQTCORETYPES_H
