/* This file is autogenerated. DO NOT CHANGE. All changes will be lost */

#ifndef SOURCE_CONTEXT_QPB_H
#define SOURCE_CONTEXT_QPB_H

#include "protobufwellknowntypes_exports.qpb.h"

#include <QtProtobuf/qprotobuflazymessagepointer.h>
#include <QtProtobuf/qprotobufmessage.h>
#include <QtProtobuf/qprotobufobject.h>
#include <QtProtobuf/qtprotobuftypes.h>

#include <QtCore/qbytearray.h>
#include <QtCore/qlist.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qshareddata.h>
#include <QtCore/qstring.h>

namespace google::protobuf {
class SourceContext;
namespace SourceContext_QtProtobufNested {
enum class QtProtobufFieldEnum;
} // namespace SourceContext_QtProtobufNested

#ifdef QT_USE_PROTOBUF_LIST_ALIASES
using SourceContextRepeated = QList<SourceContext>;
#endif // QT_USE_PROTOBUF_LIST_ALIASES

class SourceContext_QtProtobufData;
class SourceContext : public QProtobufMessage
{
    Q_PROTOBUF_OBJECT_EXPORT(QPB_PROTOBUFWELLKNOWNTYPES_EXPORT)
    Q_PROPERTY(QString fileName READ fileName WRITE setFileName SCRIPTABLE true)

public:
    using QtProtobufFieldEnum = SourceContext_QtProtobufNested::QtProtobufFieldEnum;
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT SourceContext();
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT ~SourceContext();
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT SourceContext(const SourceContext &other);
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT SourceContext &operator =(const SourceContext &other);
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT SourceContext(SourceContext &&other) noexcept;
    SourceContext &operator =(SourceContext &&other) noexcept
    {
        swap(other);
        return *this;
    }
    void swap(SourceContext &other) noexcept
    {
        QProtobufMessage::swap(other);
        dptr.swap(other.dptr);
    }
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT Q_IMPLICIT operator QVariant() const;

    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT const QString &fileName() const &;
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT void setFileName(const QString &fileName);
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT void setFileName(QString &&fileName);
    QPB_PROTOBUFWELLKNOWNTYPES_EXPORT static void registerTypes();

private:
    friend QPB_PROTOBUFWELLKNOWNTYPES_EXPORT bool comparesEqual(const SourceContext &lhs, const SourceContext &rhs) noexcept;
    friend bool operator==(const SourceContext &lhs, const SourceContext &rhs) noexcept
    {
        return comparesEqual(lhs, rhs);
    }
    friend bool operator!=(const SourceContext &lhs, const SourceContext &rhs) noexcept
    {
        return !comparesEqual(lhs, rhs);
    }
    QExplicitlySharedDataPointer<SourceContext_QtProtobufData> dptr;
};
namespace SourceContext_QtProtobufNested {
Q_NAMESPACE_EXPORT(QPB_PROTOBUFWELLKNOWNTYPES_EXPORT)

enum class QtProtobufFieldEnum {
    FileNameProtoFieldNumber = 1,
};
Q_ENUM_NS(QtProtobufFieldEnum)

} // namespace SourceContext_QtProtobufNested
} // namespace google::protobuf

#endif // SOURCE_CONTEXT_QPB_H
