#ifndef QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_h_H
#define QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_h_H

#define QT_FEATURE_protobuf_qtcoretypes 1

#define QT_FEATURE_protobuf_qtguitypes 1

#define QT_FEATURE_protobuf_wellknowntypes 1

#define QT_FEATURE_protobufquick 1


#endif // QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_h_H
