// Copyright (C) 2023 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QT_PROTOBUF_WELLKNOWN_TYPES_GLOBAL_H
#define QT_PROTOBUF_WELLKNOWN_TYPES_GLOBAL_H

#include <QtProtobuf/qtprotobufglobal.h>
#include <QtProtobufWellKnownTypes/qtprotobufwellknowntypesexports.h>

#endif // QT_PROTOBUF_WELLKNOWN_TYPES_GLOBAL_H
